@@ -37,16 +37,9 @@ if USING_PYTHON2:
     int = long
     open = io.open
     def input(prompt=None):
-        try:
-            cur_stdin, cur_stdout = sys.stdin, sys.stdout
-            if hasattr(sys.stdin, '_original_stream'):
-                sys.stdin = sys.stdin._original_stream
-            if hasattr(sys.stdout, '_original_stream'):
-                sys.stdout = sys.stdout._original_stream
-            encoded_prompt = prompt.encode(sys_encoding)
+        encoded_prompt = prompt.encode(sys_encoding)
+        with unwrap_stream("stdin"), unwrap_stream("stdout"):
             return raw_input(encoded_prompt).decode(sys_encoding)
-        finally:
-            sys.stdin, sys.stdout = cur_stdin, cur_stdout
     def expanduser(path):
         '''
         Copy of os.path.expanduser that decodes os.environ['HOME'] if necessary.
@@ -76,8 +69,14 @@ if USING_PYTHON2:
     if os.name == 'nt':
         # The POSIX os.path.expanduser doesn't work on NT, so just leave it be
         expanduser = os.path.expanduser
+    # Prior to 2.7.3, shlex is not compatible with Unicode strings, so we bundle a replacement from 2.7.6.
+    if sys.version_info < (2, 7, 3):
+        from .packages import shlex
+    else:
+        import shlex
 else:
     from io import StringIO, BytesIO
+    import shlex
     builtin_str = str
     str = str
     bytes = bytes
