@@ -328,7 +328,7 @@ def run_one_entry_point(job_id, function, input_hash, run_spec, depends_on, name
         env_path = os.path.join(job_homedir, 'environment')
         with open(env_path, 'w') as fd:
             job_input_file = os.path.join(job_homedir, 'job_input.json')
-            var_defs_hash = file_load_utils.gen_bash_vars(job_input_file)
+            var_defs_hash = file_load_utils.gen_bash_vars(job_input_file, job_homedir=job_homedir)
             for key, val in var_defs_hash.iteritems():
                 fd.write("{}={}\n".format(key, val))
 
